package PNI::Core;

use 5.10.1;

our $VERSION = '0.01';

1;

=head1 NAME

PNI::Core - Perl Node Interface core distribution

=head1 SYNOPSIS

    cpan PNI::Core

=head1 DESCRIPTION

Install L<PNI> core modules and a default set of PNI nodes.

This module also requires Perl version greater or equal than 5.10.1,

since it is highly recommended by Perl Community to upgrade previous versions.

Anyway if you want to install L<PNI> for older versions of Perl, you can do it

    cpan PNI

and then add any PNI::Node::* to your list.

=head1 SEE ALSO

L<PNI>

=cut

